<?php
// admin/cancel-invitation.php
require_once __DIR__ . '/../helpers/InvitationHelper.php';

// Set proper JSON header immediately
header('Content-Type: application/json');

// Disable any output buffering that might add whitespace
while (ob_get_level()) {
    ob_end_clean();
}

try {
    // Require admin access
    InvitationHelper::requireAdmin($pdo);
} catch (Exception $e) {
    echo json_encode(['success' => false, 'message' => 'Access denied']);
    exit;
}

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['success' => false, 'message' => 'Invalid request method']);
    exit;
}

$invitationId = $_POST['invitation_id'] ?? null;
$organizationId = $_SESSION['organization_id'];

if (!$invitationId || !is_numeric($invitationId)) {
    echo json_encode(['success' => false, 'message' => 'Invalid invitation ID']);
    exit;
}

try {
    // Update invitation status to cancelled
    $stmt = $pdo->prepare("
        UPDATE whsale_inventory_pro_invitations 
        SET status = 'cancelled', updated_at = NOW() 
        WHERE id = ? AND organization_id = ? AND status = 'pending'
    ");
    $stmt->execute([$invitationId, $organizationId]);
    
    if ($stmt->rowCount() > 0) {
        echo json_encode(['success' => true, 'message' => 'Invitation cancelled successfully']);
    } else {
        echo json_encode(['success' => false, 'message' => 'Invitation not found or already processed']);
    }
    
} catch (Exception $e) {
    error_log("Error cancelling invitation: " . $e->getMessage());
    echo json_encode(['success' => false, 'message' => 'Server error occurred']);
}
?>