<?php
// config/config.php
/**
 * Multi-Domain Configuration for Ibeam Inventory Pro
 */

// Get the current domain
$currentDomain = $_SERVER['HTTP_HOST'];

// Configure your domains here
$devDomain = 'ibeamma.com';  // Your current development domain
$publicDomains = [
    'storvara.com',      // Replace with your actual new domain
    'www.storvara.com'   // Replace with your actual new domain
];

// Combine all allowed domains
$allAllowedDomains = array_merge([$devDomain], $publicDomains);

// Security check - only allow specific domains
if (!in_array($currentDomain, $allAllowedDomains)) {
    header('HTTP/1.1 403 Forbidden');
    exit('Domain not allowed: ' . htmlspecialchars($currentDomain));
}

// Determine if this is a public domain request
$isPublicDomain = in_array($currentDomain, $publicDomains);

// Set base URLs based on current domain
if ($isPublicDomain) {
    // User is accessing via public domain - clean URLs
    define('BASE_URL', 'https://' . $currentDomain . '/');
    define('ADMIN_BASE_URL', 'https://' . $devDomain . '/IbeamInventoryPro3/');  // Keep admin on dev domain
    define('API_BASE_URL', 'https://' . $devDomain . '/IbeamInventoryPro3/');    // Keep API on dev domain
    define('IS_PUBLIC_DOMAIN', true);
    define('CURRENT_DOMAIN_TYPE', 'public');
    
    // Upload paths for public domain
    define('UPLOAD_DIR', __DIR__ . '/../uploads/item_photos/');
    define('UPLOAD_URL', BASE_URL . 'uploads/item_photos/');
} else {
    // User is accessing via dev domain - keep existing structure
    define('BASE_URL', 'https://' . $currentDomain . '/IbeamInventoryPro3/');
    define('ADMIN_BASE_URL', 'https://' . $currentDomain . '/IbeamInventoryPro3/');
    define('API_BASE_URL', 'https://' . $currentDomain . '/IbeamInventoryPro3/');
    define('IS_PUBLIC_DOMAIN', false);
    define('CURRENT_DOMAIN_TYPE', 'development');
    
    // Upload paths for dev domain (existing structure)
    define('UPLOAD_DIR', __DIR__ . '/../uploads/item_photos/');
    define('UPLOAD_URL', BASE_URL . 'uploads/item_photos/');
}

// Common app constants
define('APP_NAME', 'Ibeam Inventory Pro');

// Additional useful constants
define('CURRENT_DOMAIN', $currentDomain);
define('CURRENT_BASE_URL', 'https://' . $currentDomain);

// Force HTTPS on public domain
if (IS_PUBLIC_DOMAIN && (!isset($_SERVER['HTTPS']) || $_SERVER['HTTPS'] !== 'on')) {
    $redirectURL = 'https://' . $currentDomain . $_SERVER['REQUEST_URI'];
    header("Location: $redirectURL", true, 301);
    exit();
}

// Optional: Redirect admin URLs to dev domain when accessed from public domain
if (IS_PUBLIC_DOMAIN && (strpos($_SERVER['REQUEST_URI'], '/admin') === 0 || strpos($_SERVER['REQUEST_URI'], '/dashboard') === 0)) {
    $redirectURL = 'https://' . $devDomain . '/IbeamInventoryPro3' . $_SERVER['REQUEST_URI'];
    header("Location: $redirectURL", true, 301);
    exit();
}

// Hide debug info on public domain
if (IS_PUBLIC_DOMAIN) {
    ini_set('display_errors', 0);
    error_reporting(0);
} else {
    // Keep your existing debug settings for dev domain
    ini_set('display_errors', 1);
    error_reporting(E_ALL);
}

/**
 * Helper functions for your application
 */

function getPublicUrl($path = '') {
    if (IS_PUBLIC_DOMAIN) {
        return BASE_URL . ltrim($path, '/');
    } else {
        return BASE_URL . ltrim($path, '/');
    }
}

function getAdminUrl($path = '') {
    return ADMIN_BASE_URL . ltrim($path, '/');
}

function getApiUrl($path = '') {
    return API_BASE_URL . ltrim($path, '/');
}

function isPublicDomain() {
    return IS_PUBLIC_DOMAIN;
}

function getCurrentDomainType() {
    return CURRENT_DOMAIN_TYPE;
}

// Storefront URL generation for organization slugs
function getStorefrontUrl($organizationSlug) {
    if (IS_PUBLIC_DOMAIN) {
        // Clean URLs for public domain: storvara.com/organization-slug
        return BASE_URL . $organizationSlug;
    } else {
        // Your existing dev URL structure: ibeamma.com/IbeamInventoryPro3/storefront/organization-slug
        return BASE_URL . 'storefront/' . $organizationSlug;
    }
}

// Session handling for different domains
if (IS_PUBLIC_DOMAIN) {
    // Set session cookie domain for public domain
    ini_set('session.cookie_domain', '.' . str_replace('www.', '', $currentDomain));
}

?>