<?php
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../config/db.php';
require_once __DIR__ . '/../helpers/AuthHelper.php';

class StorefrontController
{
    public static function showIndex($organization_slug)
    {
        global $pdo;

        error_log("[StorefrontController] showIndex called with slug: $organization_slug");

        $stmt = $pdo->prepare("
            SELECT organization_id 
            FROM whsale_inventory_pro_users 
            WHERE organization_slug = ? 
            LIMIT 1
        ");
        $stmt->execute([$organization_slug]);
        $org = $stmt->fetch();

        if (!$org) {
            error_log("[StorefrontController] No matching organization for slug: $organization_slug");
            http_response_code(404);
            echo "Organization not found.";
            return;
        }

        error_log("[StorefrontController] Found org ID: {$org['organization_id']}");

        $stmt = $pdo->prepare("
            SELECT * 
            FROM whsale_inventory_pro_storefront_products 
            WHERE organization_id = ? AND is_active = 1
            ORDER BY created_at DESC
        ");
        $stmt->execute([$org['organization_id']]);
        $products = $stmt->fetchAll();

        error_log("[StorefrontController] Loaded " . count($products) . " active product(s)");

        require __DIR__ . '/../views/storefront/index.php';
    }

    public static function showProduct($slug, $receiving_id)
    {
        global $pdo;

        error_log("[StorefrontController] showProduct called with slug: $slug and receiving_id: $receiving_id");

        // ✅ Fetch org ID by slug
        $stmt = $pdo->prepare("
            SELECT organization_id 
            FROM whsale_inventory_pro_users 
            WHERE organization_slug = ? 
            LIMIT 1
        ");
        $stmt->execute([$slug]);
        $org = $stmt->fetch();

        if (!$org) {
            http_response_code(404);
            echo "Invalid organization.";
            return;
        }

        error_log("[StorefrontController] Found org ID: {$org['organization_id']}");

        // ✅ Fetch product
        $stmt = $pdo->prepare("
            SELECT s.*, r.vendor_name, r.po_number, r.delivery_date, r.notes, u.email AS seller_email
            FROM whsale_inventory_pro_storefront_products s
            JOIN whsale_inventory_pro_receiving_log r ON s.receiving_id = r.id
            JOIN whsale_inventory_pro_users u ON r.created_by = u.id
            WHERE s.receiving_id = ? AND s.organization_id = ?
        ");
        $stmt->execute([$receiving_id, $org['organization_id']]);
        $product = $stmt->fetch();

        if (!$product) {
            http_response_code(404);
            echo "Product not found.";
            return;
        }

        error_log("[StorefrontController] Loaded product: {$product['title']}");

        // ✅ Fetch photos
        $photoStmt = $pdo->prepare("
            SELECT file_path, caption
            FROM whsale_inventory_pro_receiving_photos
            WHERE receiving_id = ?
            ORDER BY uploaded_at DESC
        ");
        $photoStmt->execute([$receiving_id]);
        $photos = $photoStmt->fetchAll();

        // ✅ Pass slug to view explicitly
        $organization_slug = $slug;

        require __DIR__ . '/../views/storefront/view.php';
    }

    public static function showConfirmation($receiving_id)
    {
        global $pdo;

        AuthHelper::requireLogin();

        $stmt = $pdo->prepare("
            SELECT s.title, s.description, s.created_at, r.vendor_name, u.organization_slug
            FROM whsale_inventory_pro_storefront_products s
            JOIN whsale_inventory_pro_receiving_log r ON s.receiving_id = r.id
            JOIN whsale_inventory_pro_users u ON r.created_by = u.id
            WHERE s.receiving_id = ?
        ");
        $stmt->execute([$receiving_id]);
        $listing = $stmt->fetch();

        if (!$listing) {
            $error = "Listing not found.";
        }

        require __DIR__ . '/../views/storefront/confirmation.php';
    }
}
