<?php
class Router
{
    private $routes = [];

    public function get($path, $handler)
    {
        $this->routes['GET'][$path] = $handler;
    }

    public function post($path, $handler)
    {
        $this->routes['POST'][$path] = $handler;
    }

    public function dispatch($uri)
    {
        $method = $_SERVER['REQUEST_METHOD'];
        error_log("[Router] Dispatching URI: $uri (method: $method)");

        // ✅ Match exact static routes
        if (isset($this->routes[$method][$uri])) {
            error_log("[Router] Matched static route: $uri");
            $this->execute($this->routes[$method][$uri]);
            return;
        }

        // ✅ Match dynamic routes like (:any) or (:num)
        foreach ($this->routes[$method] as $routePattern => $handler) {
            $pattern = preg_replace('/\(:any\)/', '([^/]+)', $routePattern);
            $pattern = preg_replace('/\(:num\)/', '(\d+)', $pattern);
            $pattern = "#^" . $pattern . "$#";

            if (preg_match($pattern, $uri, $matches)) {
                array_shift($matches); // Remove full match
                error_log("[Router] Matched dynamic route: $routePattern with params: " . json_encode($matches));
                $this->execute($handler, $matches);
                return;
            }
        }

        // ❌ No match found
        http_response_code(404);
        error_log("[Router] No match found for: $uri");
        echo "<h2>404 - Page Not Found</h2>";
    }

    public function execute($handler, $params = [])
    {
        require_once __DIR__ . '/../config/config.php';
        require_once __DIR__ . '/../config/db.php';
        require_once __DIR__ . '/AuthHelper.php';
        global $pdo;

        // ✅ Handle controller-style handler first
        if (is_array($handler) && count($handler) === 2 && method_exists($handler[0], $handler[1])) {
            error_log("[Router] Executing controller method: " . implode('::', $handler));
            call_user_func_array($handler, $params);
        }
        // ✅ Handle inline closure functions
        elseif (is_callable($handler)) {
            error_log("[Router] Executing closure or named function");
            call_user_func_array($handler, $params);
        }
        // ✅ Load view file
        elseif (is_string($handler)) {
            error_log("[Router] Including static view: $handler");
            require $handler;
        }
        // ❌ Invalid handler fallback
        else {
            http_response_code(500);
            error_log("[Router] Invalid handler: " . var_export($handler, true));
            echo "<h2>Internal Server Error: Invalid route handler.</h2>";
        }
    }
}
