<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Require specific permission for deleting inventory
AuthHelper::requirePermission('delete_inventory');

$item_id = $_POST['item_id'] ?? null;
$receiving_id = $_POST['receiving_id'] ?? null;
$confirm_delete = $_POST['confirm_delete'] ?? null;
$organization_id = $_SESSION['organization_id'];

if (!$item_id || !is_numeric($item_id)) {
    $_SESSION['error'] = "Invalid item ID.";
    header("Location: " . BASE_URL . "inventory");
    exit;
}

if (!$confirm_delete) {
    $_SESSION['error'] = "Delete confirmation required.";
    header("Location: " . BASE_URL . "inventory");
    exit;
}

$user_id = AuthHelper::getUserId();

try {
    // UPDATED: Enhanced security - verify item belongs to user's organization
    $stmt = $pdo->prepare("
        SELECT id, product_name, receiving_id 
        FROM whsale_inventory_pro_inventory_items 
        WHERE id = ? AND organization_id = ?
    ");
    $stmt->execute([$item_id, $organization_id]);
    $item = $stmt->fetch();
    
    if (!$item) {
        $_SESSION['error'] = "Item not found or you don't have permission to delete it.";
        header("Location: " . BASE_URL . "inventory");
        exit;
    }

    // Perform soft delete
    $stmt = $pdo->prepare("CALL whsale_inventory_pro_soft_delete_inventory_item(?, ?)");
    $stmt->execute([$item_id, $user_id]);
    $stmt->closeCursor();
    
    $_SESSION['success'] = "Inventory item '{$item['product_name']}' has been deleted successfully.";
    
} catch (Exception $e) {
    error_log("Soft delete failed: " . $e->getMessage());
    $_SESSION['error'] = "Failed to delete inventory item. Please try again.";
}

// UPDATED: Smart redirect based on context
if ($receiving_id && is_numeric($receiving_id)) {
    // Redirect back to the receiving log view
    header("Location: " . BASE_URL . "receiving/view?id=" . urlencode($receiving_id));
} elseif ($item && $item['receiving_id']) {
    // Use the item's receiving_id if available
    header("Location: " . BASE_URL . "receiving/view?id=" . urlencode($item['receiving_id']));
} else {
    // Default to inventory management
    header("Location: " . BASE_URL . "inventory/manage");
}
exit;