<?php
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../config/db.php';
require_once __DIR__ . '/../helpers/AuthHelper.php';

$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $email = trim($_POST['email'] ?? '');
    $password = $_POST['password'] ?? '';
    
    if ($email && $password) {
        $stmt = $pdo->prepare("CALL whsale_inventory_pro_login_user(?)");
        $stmt->execute([$email]);
        $user = $stmt->fetch();
        $stmt->closeCursor();
        
        if ($user && password_verify($password, $user['password_hash'])) {
            // Check account status BEFORE allowing login
            $accountStatus = $user['account_status'] ?? 'active';
            
            switch ($accountStatus) {
                case 'suspended':
                    $error = "Your account has been suspended. Please contact your administrator for assistance.";
                    break;
                    
                case 'pending':
                    $error = "Your account is still pending activation. Please complete your invitation or contact your administrator.";
                    break;
                    
                case 'active':
                    // Account is active, proceed with login
                    session_start();
                    $_SESSION['user_id'] = $user['id'];
                    $_SESSION['username'] = $user['email'];
                    $_SESSION['first_name'] = $user['first_name'];
                    $_SESSION['last_name'] = $user['last_name'];
                    $_SESSION['organization_id'] = $user['organization_id'];
                    $_SESSION['organization_slug'] = $user['organization_slug'];
                    $_SESSION['role'] = $user['role'];
                    
                    // Set user role in session for role-based access control
                    AuthHelper::setUserRole($user['id'], $pdo);
                    
                    // Update account status to active if needed (for existing users)
                    try {
                        $stmt = $pdo->prepare("
                            UPDATE whsale_inventory_pro_users 
                            SET account_status = 'active' 
                            WHERE id = ? AND (account_status IS NULL OR account_status = 'pending')
                        ");
                        $stmt->execute([$user['id']]);
                    } catch (Exception $e) {
                        error_log("Error updating account status: " . $e->getMessage());
                    }
                    
                    header("Location: " . BASE_URL . "dashboard");
                    exit;
                    break;
                    
                default:
                    $error = "Your account status is unknown. Please contact your administrator.";
                    break;
            }
        } else {
            $error = "Invalid email or password.";
        }
    } else {
        $error = "Please enter both email and password.";
    }
}
?>

<?php include __DIR__ . '/partials/auth_head.php'; ?>

<style>
    .btn-custom-green {
        background-color: #00f801;
        border-color: #00f801;
        color: #000;
    }
    .btn-custom-green:hover {
        background-color: #00df01;
        border-color: #00df01;
        color: #000;
    }
    .logo-header img {
        max-height: 120px;
    }
    .card-header {
        background-color: #ffffff !important;
        border-bottom: 1px solid #dee2e6;
    }
    .alert-warning {
        border-left: 4px solid #ffc107;
    }
    .alert-danger {
        border-left: 4px solid #dc3545;
    }
</style>

<div class="container vh-100 d-flex align-items-center justify-content-center">
    <div class="col-12 col-sm-10 col-md-8 col-lg-6 col-xl-5">
        <div class="card border-0 shadow-lg rounded-4">
            <div class="card-header text-center py-4 bg-white">
                <div class="logo-header mb-3">
                    <img src="<?= BASE_URL ?>assets/logo.png" alt="<?= APP_NAME ?> Logo" class="img-fluid">
                </div>
                <h4 class="mb-0 fw-bold text-dark">Sign In</h4>
            </div>
            <div class="card-body p-5 bg-white">
                <?php if ($error): ?>
                    <div class="alert <?= strpos($error, 'suspended') !== false ? 'alert-warning' : 'alert-danger' ?> text-center small">
                        <i class="fas fa-<?= strpos($error, 'suspended') !== false ? 'pause-circle' : 'exclamation-circle' ?> me-2"></i>
                        <?= htmlspecialchars($error) ?>
                    </div>
                <?php endif; ?>
                
                <form method="POST" novalidate>
                    <div class="form-floating mb-4">
                        <input type="email" class="form-control" id="email" name="email" 
                               placeholder="name@example.com" required autofocus 
                               value="<?= htmlspecialchars($_POST['email'] ?? '') ?>">
                        <label for="email">Email address</label>
                    </div>
                    <div class="form-floating mb-4">
                        <input type="password" class="form-control" id="password" name="password" placeholder="Password" required>
                        <label for="password">Password</label>
                    </div>
                    <div class="d-grid mb-3">
                        <button type="submit" class="btn btn-custom-green btn-lg">Sign In</button>
                    </div>
                </form>
                
                <div class="text-center mt-3">
                    <small class="text-muted">
                        Don't have an account?
                        <a href="<?= BASE_URL ?>register" class="text-decoration-none fw-semibold">Sign up here</a>.
                    </small>
                </div>
            </div>
        </div>
    </div>
</div>

<?php include __DIR__ . '/partials/footer.php'; ?>