<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Require specific permission for managing photos
AuthHelper::requirePermissionAjax('manage_receiving_photos');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $photo_id = $_POST['photo_id'] ?? null;
    $caption = trim($_POST['caption'] ?? '');
    $user_id = AuthHelper::getUserId();
    $organization_id = $_SESSION['organization_id'];

    if ($photo_id && is_numeric($photo_id)) {
        try {
            // UPDATED: Enhanced security - check photo belongs to user's organization
            $stmt = $pdo->prepare("
                SELECT rp.id, rp.uploaded_by, rl.organization_id 
                FROM whsale_inventory_pro_receiving_photos rp
                JOIN whsale_inventory_pro_receiving_log rl ON rp.receiving_id = rl.id
                WHERE rp.id = ?
            ");
            $stmt->execute([$photo_id]);
            $photo = $stmt->fetch();
            
            if (!$photo) {
                echo json_encode(['success' => false, 'message' => 'Photo not found']);
                exit;
            }
            
            // Check if user has permission to edit this photo
            if ($photo['organization_id'] != $organization_id) {
                echo json_encode(['success' => false, 'message' => 'Access denied']);
                exit;
            }
            
            // Allow editing if user uploaded the photo OR has manage_receiving_photos permission
            $canEdit = ($photo['uploaded_by'] == $user_id) || RoleHelper::hasPermission('manage_receiving_photos');
            
            if (!$canEdit) {
                echo json_encode(['success' => false, 'message' => 'Permission denied']);
                exit;
            }
            
            // Update caption
            $stmt = $pdo->prepare("
                UPDATE whsale_inventory_pro_receiving_photos 
                SET caption = ?
                WHERE id = ?
            ");
            $stmt->execute([$caption, $photo_id]);
            
            echo json_encode([
                'success' => true, 
                'message' => 'Caption updated successfully',
                'caption' => $caption
            ]);
            exit;
            
        } catch (Exception $e) {
            error_log("Error updating photo caption: " . $e->getMessage());
            echo json_encode(['success' => false, 'message' => 'Database error']);
            exit;
        }
    }
}

echo json_encode(['success' => false, 'message' => 'Invalid request']);
exit;