<?php
require_once __DIR__ . '/../../config/config.php';
require_once __DIR__ . '/../../config/db.php';
require_once __DIR__ . '/../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../helpers/RoleHelper.php';

// UPDATED: Require specific permission for uploading photos
AuthHelper::requirePermission('upload_receiving_photos');

$receiving_id = $_GET['receiving_id'] ?? $_POST['receiving_id'] ?? null;
if (!$receiving_id || !is_numeric($receiving_id)) {
    header("Location: " . BASE_URL . "receiving");
    exit;
}

$_SESSION['came_from_receiving_view'] = $receiving_id;

$error = '';
$success = '';
$redirect_after_success = false;

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_FILES['photo'])) {
    $upload_dir = __DIR__ . '/../../public/uploads/receiving/';
    $caption = trim($_POST['caption'] ?? '');
    $uploaded_by = AuthHelper::getUserId();

    if (!is_dir($upload_dir)) {
        mkdir($upload_dir, 0755, true);
    }

    $file = $_FILES['photo'];
    $extension = strtolower(pathinfo($file['name'], PATHINFO_EXTENSION));
    $allowed = ['jpg', 'jpeg', 'png', 'gif', 'webp', 'heic', 'heif'];

    if (!in_array($extension, $allowed)) {
        $error = "Invalid file type. Allowed: JPG, PNG, GIF, WEBP, HEIC.";
    } elseif ($file['error'] !== UPLOAD_ERR_OK) {
        $error = "File upload error.";
    } else {
        $filename = uniqid('receiving_') . '.' . $extension;
        $filepath = $upload_dir . $filename;

        if (move_uploaded_file($file['tmp_name'], $filepath)) {
            $stmt = $pdo->prepare("
                INSERT INTO whsale_inventory_pro_receiving_photos 
                (receiving_id, file_path, caption, uploaded_by)
                VALUES (?, ?, ?, ?)
            ");
            $stmt->execute([$receiving_id, $filename, $caption, $uploaded_by]);

            $success = "Photo uploaded successfully.";
            $redirect_after_success = true;
        } else {
            $error = "Failed to save uploaded file.";
        }
    }
}
?>

<?php include __DIR__ . '/../partials/head.php'; ?>
<?php include __DIR__ . '/../partials/spinner_overlay.php'; ?>

<div class="container mt-4 mb-5">
    <div class="d-flex align-items-center mb-3">
        <h4 class="mb-0">Upload Photo for Receiving Log #<?= htmlspecialchars($receiving_id) ?></h4>
        <div class="ms-auto">
            <?= RoleHelper::getRoleBadge() ?>
        </div>
    </div>

    <!-- UPDATED: Add permission info card -->
    <div class="alert alert-info mb-4">
        <div class="d-flex align-items-center">
            <i class="fas fa-info-circle me-2"></i>
            <div>
                <strong>Photo Upload Guidelines:</strong>
                <ul class="mb-0 mt-1">
                    <li>Supported formats: JPG, PNG, GIF, WEBP, HEIC</li>
                    <li>Photos help document the condition and contents of deliveries</li>
                    <li>Add captions to provide context for your team</li>
                </ul>
            </div>
        </div>
    </div>

    <?php if ($success): ?>
        <div class="alert alert-success">
            <i class="fas fa-check-circle me-2"></i>
            <?= htmlspecialchars($success) ?>
        </div>
        <script>
            document.addEventListener('DOMContentLoaded', () => {
                setTimeout(() => {
                    window.location.href = "<?= BASE_URL ?>receiving/view?id=<?= urlencode($receiving_id) ?>";
                }, 500);
            });
        </script>
    <?php elseif ($error): ?>
        <div class="alert alert-danger">
            <i class="fas fa-exclamation-circle me-2"></i>
            <?= htmlspecialchars($error) ?>
        </div>
    <?php endif; ?>

    <form method="POST" enctype="multipart/form-data" class="card p-4 shadow-sm border-0 bg-white" onsubmit="showSpinner()">
        <input type="hidden" name="receiving_id" value="<?= htmlspecialchars($receiving_id) ?>">

        <div class="mb-3">
            <label class="form-label">Photo <span class="text-danger">*</span></label>
            <input type="file" name="photo" class="form-control" accept="image/*" required onchange="previewImage(event)">
            <div class="form-text">
                <i class="fas fa-camera me-1"></i>
                Select a photo from your device or take a new one
            </div>
            
            <!-- UPDATED: Add image preview -->
            <div id="imagePreview" class="mt-2 d-none">
                <img id="previewImg" class="img-thumbnail" style="max-width: 200px; max-height: 200px;">
            </div>
        </div>

        <div class="mb-3">
            <label class="form-label">Caption (Optional)</label>
            <input type="text" name="caption" class="form-control" maxlength="255" 
                   placeholder="Describe what's shown in the photo...">
            <div class="form-text">
                <i class="fas fa-info-circle me-1"></i>
                Help your team understand what's in the photo
            </div>
        </div>

        <div class="d-flex gap-2 flex-wrap">
            <button class="btn btn-dark">
                <i class="fas fa-upload me-1"></i>Upload Photo
            </button>
            <a href="<?= BASE_URL ?>receiving/view?id=<?= urlencode($receiving_id) ?>" class="btn btn-outline-secondary">
                <i class="fas fa-arrow-left me-1"></i>Back to Log
            </a>
        </div>
    </form>
</div>

<!-- UPDATED: Enhanced JavaScript with image preview -->
<script>
function showSpinner() {
    const overlay = document.getElementById('globalSpinnerOverlay');
    if (overlay) {
        overlay.classList.remove('d-none');
        overlay.style.opacity = 0;
        overlay.style.transition = 'opacity 0.3s ease-in-out';
        setTimeout(() => overlay.style.opacity = 1, 10);
    }
}

function previewImage(event) {
    const file = event.target.files[0];
    const preview = document.getElementById('imagePreview');
    const previewImg = document.getElementById('previewImg');
    
    if (file) {
        const reader = new FileReader();
        reader.onload = function(e) {
            previewImg.src = e.target.result;
            preview.classList.remove('d-none');
        };
        reader.readAsDataURL(file);
    } else {
        preview.classList.add('d-none');
    }
}

// Show file size warning for large files
document.addEventListener('DOMContentLoaded', function() {
    const fileInput = document.querySelector('input[type="file"]');
    
    fileInput.addEventListener('change', function(e) {
        const file = e.target.files[0];
        if (file && file.size > 5 * 1024 * 1024) { // 5MB
            alert('Warning: Large files may take longer to upload. Consider compressing the image for faster upload.');
        }
    });
});
</script>

<!-- UPDATED: Custom CSS for mobile optimization -->
<style>
/* Image preview styling */
#imagePreview {
    text-align: center;
}

#previewImg {
    border-radius: 8px;
    box-shadow: 0 2px 4px rgba(0,0,0,0.1);
}

/* Mobile file input improvements */
@media (max-width: 768px) {
    .form-control[type="file"] {
        padding: 0.5rem;
    }
    
    .btn {
        width: 100%;
        margin-bottom: 0.5rem;
    }
    
    .d-flex.gap-2.flex-wrap {
        flex-direction: column;
    }
}

/* Upload progress styling */
.spinner-border {
    margin-right: 0.5rem;
}

/* Permission badge styling */
.alert-info {
    border-left: 4px solid #0dcaf0;
}
</style>

<?php include __DIR__ . '/../partials/footer.php'; ?>