<?php
require_once __DIR__ . '/../../../config/config.php';
require_once __DIR__ . '/../../../config/db.php';
require_once __DIR__ . '/../../../helpers/AuthHelper.php';
require_once __DIR__ . '/../../../helpers/RoleHelper.php';

// UPDATED: Require specific permission for managing storefront branding
AuthHelper::requirePermission('manage_storefront_branding');

$organization_id = $_SESSION['organization_id'];
$success = '';
$error = '';

// Handle Delete Logo Request
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['delete_logo'])) {
    // UPDATED: Enhanced security - verify logo belongs to user's organization
    $stmt = $pdo->prepare("SELECT logo_path FROM whsale_inventory_pro_org_branding WHERE organization_id = ?");
    $stmt->execute([$organization_id]);
    $logoPath = $stmt->fetchColumn();

    if ($logoPath) {
        $fullPath = __DIR__ . '/../../../public/uploads/logos/' . $logoPath;
        if (file_exists($fullPath)) {
            unlink($fullPath);
        }

        $update = $pdo->prepare("UPDATE whsale_inventory_pro_org_branding SET logo_path = NULL WHERE organization_id = ?");
        $update->execute([$organization_id]);
        $success = "Logo deleted successfully.";
    } else {
        $error = "No logo found to delete.";
    }
}

// Handle Profile Save
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['save_profile'])) {
    $displayName = trim($_POST['organization_display_name'] ?? '');
    $primaryColor = $_POST['primary_color'] ?? '#f66903';
    $secondaryColor = $_POST['secondary_color'] ?? '#ff9e49';
    $navbarBgColor = $_POST['navbar_bg_color'] ?? '#ffffff';
    $navbarTextColor = $_POST['navbar_text_color'] ?? '#000000';
    $bodyBgColor = $_POST['body_bg_color'] ?? '#f8f9fa';
    $priceColor = $_POST['price_color'] ?? '#198754';
    $headingColor = $_POST['heading_color'] ?? '#212529';
    $bodyTextColor = $_POST['body_text_color'] ?? '#212529';
    $mutedTextColor = $_POST['muted_text_color'] ?? '#6c757d';
    $cardBgColor = $_POST['card_bg_color'] ?? '#ffffff';
    $cardBorderColor = $_POST['card_border_color'] ?? '#dee2e6';
    $linkColor = $_POST['link_color'] ?? '#0d6efd';
    $filename = null;

    // Handle logo upload
    $logo = $_FILES['logo'] ?? null;
    if ($logo && isset($logo['error']) && $logo['error'] === 0) {
        if (is_uploaded_file($logo['tmp_name']) && $logo['size'] <= 2 * 1024 * 1024) {
            $ext = pathinfo($logo['name'], PATHINFO_EXTENSION);
            $filename = 'logo_' . $organization_id . '_' . time() . '.' . $ext;
            $targetDir = __DIR__ . '/../../../public/uploads/logos/';
            $targetPath = $targetDir . $filename;

            if (!is_dir($targetDir)) mkdir($targetDir, 0777, true);

            if (!move_uploaded_file($logo['tmp_name'], $targetPath)) {
                $error = "Failed to upload logo.";
            }
        } else {
            $error = "Invalid logo file. Max size: 2MB.";
        }
    } elseif ($logo && isset($logo['error']) && $logo['error'] !== UPLOAD_ERR_NO_FILE && $logo['error'] !== 0) {
        $error = "File upload error occurred.";
    }

    if (!$error) {
        // UPDATED: Enhanced security - verify branding record belongs to user's organization
        $stmt = $pdo->prepare("SELECT id FROM whsale_inventory_pro_org_branding WHERE organization_id = ?");
        $stmt->execute([$organization_id]);
        $brandingExists = $stmt->fetch();

        $fields = [
            'organization_display_name' => $displayName,
            'primary_color' => $primaryColor,
            'secondary_color' => $secondaryColor,
            'navbar_bg_color' => $navbarBgColor,
            'navbar_text_color' => $navbarTextColor,
            'body_bg_color' => $bodyBgColor,
            'price_color' => $priceColor,
            'heading_color' => $headingColor,
            'body_text_color' => $bodyTextColor,
            'muted_text_color' => $mutedTextColor,
            'card_bg_color' => $cardBgColor,
            'card_border_color' => $cardBorderColor,
            'link_color' => $linkColor
        ];

        if ($filename) {
            $fields['logo_path'] = $filename;
        }

        if ($brandingExists) {
            // Update existing record for this organization only
            $setParts = [];
            $params = [];

            foreach ($fields as $column => $value) {
                $setParts[] = "$column = ?";
                $params[] = $value;
            }

            $params[] = $organization_id;

            $sql = "UPDATE whsale_inventory_pro_org_branding SET " . implode(', ', $setParts) . " WHERE organization_id = ?";
            $stmt = $pdo->prepare($sql);
            $stmt->execute($params);
        } else {
            // Insert new record for this organization
            $fields['organization_id'] = $organization_id;
            
            $columns = array_keys($fields);
            $placeholders = array_fill(0, count($fields), '?');
            
            $sql = "INSERT INTO whsale_inventory_pro_org_branding (" . implode(', ', $columns) . ") VALUES (" . implode(', ', $placeholders) . ")";
            $stmt = $pdo->prepare($sql);
            $stmt->execute(array_values($fields));
        }

        $success = "Storefront profile updated successfully.";
    }
}

// UPDATED: Enhanced security - fetch branding for user's organization only
$stmt = $pdo->prepare("SELECT * FROM whsale_inventory_pro_org_branding WHERE organization_id = ?");
$stmt->execute([$organization_id]);
$org = $stmt->fetch();

// If no branding exists, create default values
if (!$org) {
    $org = [
        'logo_path' => null,
        'organization_display_name' => '',
        'primary_color' => '#f66903',
        'secondary_color' => '#ff9e49',
        'navbar_bg_color' => '#ffffff',
        'navbar_text_color' => '#000000',
        'body_bg_color' => '#f8f9fa',
        'price_color' => '#198754',
        'heading_color' => '#212529',
        'body_text_color' => '#212529',
        'muted_text_color' => '#6c757d',
        'card_bg_color' => '#ffffff',
        'card_border_color' => '#dee2e6',
        'link_color' => '#0d6efd'
    ];
}

include __DIR__ . '/../../partials/head.php';
?>

<div class="container mt-4 mb-5">
    <div class="row">
        <div class="col-lg-8 mx-auto">
            <div class="d-flex align-items-center mb-4">
                <h4 class="mb-0 me-3">
                    <i class="fas fa-palette me-2"></i>Edit Storefront Profile
                </h4>
                <div class="ms-auto">
                    <?= RoleHelper::getRoleBadge() ?>
                </div>
            </div>

            <?php if ($error): ?>
                <div class="alert alert-danger">
                    <i class="fas fa-exclamation-circle me-2"></i>
                    <?= htmlspecialchars($error) ?>
                </div>
            <?php elseif ($success): ?>
                <div class="alert alert-success">
                    <i class="fas fa-check-circle me-2"></i>
                    <?= htmlspecialchars($success) ?>
                </div>
            <?php endif; ?>

            <form method="POST" enctype="multipart/form-data">
                <!-- Branding Section -->
                <div class="card mb-4 shadow-sm">
                    <div class="card-header bg-light">
                        <h5 class="mb-0"><i class="fas fa-store me-2"></i>Store Branding</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="organization_display_name" name="organization_display_name"
                                   placeholder="Bob's Discount Grocery"
                                   value="<?= htmlspecialchars($org['organization_display_name'] ?? '') ?>">
                            <label for="organization_display_name">
                                <i class="fas fa-tag me-2"></i>Storefront Display Name
                            </label>
                            <div class="form-text">This appears when no logo is uploaded</div>
                        </div>

                        <div class="mb-3">
                            <label for="logo" class="form-label">
                                <i class="fas fa-image me-2"></i>Upload Logo
                            </label>
                            <input type="file" class="form-control" id="logo" name="logo" accept="image/*">
                            <div class="form-text">Maximum file size: 2MB. Recommended formats: PNG, JPG, SVG</div>
                        </div>

                        <?php if (!empty($org['logo_path'])): ?>
                            <div class="mb-3">
                                <p class="fw-semibold">Current Logo:</p>
                                <div class="border rounded p-3 bg-light d-inline-block">
                                    <img src="<?= BASE_URL ?>public/uploads/logos/<?= htmlspecialchars($org['logo_path']) ?>"
                                         alt="Current Logo" style="max-height: 120px; max-width: 300px;">
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>

                <!-- Color Scheme Section -->
                <div class="card mb-4 shadow-sm">
                    <div class="card-header bg-light">
                        <h5 class="mb-0"><i class="fas fa-palette me-2"></i>Color Scheme</h5>
                    </div>
                    <div class="card-body">
                        <div class="row mb-3">
                            <div class="col-md-6">
                                <label for="primary_color" class="form-label">
                                    <i class="fas fa-circle me-2" style="color: <?= htmlspecialchars($org['primary_color'] ?? '#f66903') ?>"></i>
                                    Primary Brand Color
                                </label>
                                <input type="color" class="form-control form-control-color" id="primary_color" name="primary_color"
                                       value="<?= htmlspecialchars($org['primary_color'] ?? '#f66903') ?>">
                                <div class="form-text">Used for buttons, links, and product titles</div>
                            </div>
                            <div class="col-md-6">
                                <label for="secondary_color" class="form-label">
                                    <i class="fas fa-circle me-2" style="color: <?= htmlspecialchars($org['secondary_color'] ?? '#ff9e49') ?>"></i>
                                    Secondary Accent Color
                                </label>
                                <input type="color" class="form-control form-control-color" id="secondary_color" name="secondary_color"
                                       value="<?= htmlspecialchars($org['secondary_color'] ?? '#ff9e49') ?>">
                                <div class="form-text">Used for hover effects and accents</div>
                            </div>
                        </div>

                        <div class="row mb-3">
                            <div class="col-md-6">
                                <label for="price_color" class="form-label">
                                    <i class="fas fa-dollar-sign me-2" style="color: <?= htmlspecialchars($org['price_color'] ?? '#198754') ?>"></i>
                                    Price Display Color
                                </label>
                                <input type="color" class="form-control form-control-color" id="price_color" name="price_color"
                                       value="<?= htmlspecialchars($org['price_color'] ?? '#198754') ?>">
                                <div class="form-text">Color used for product pricing</div>
                            </div>
                            <div class="col-md-6">
                                <label for="body_bg_color" class="form-label">
                                    <i class="fas fa-fill me-2" style="color: <?= htmlspecialchars($org['body_bg_color'] ?? '#f8f9fa') ?>"></i>
                                    Page Background
                                </label>
                                <input type="color" class="form-control form-control-color" id="body_bg_color" name="body_bg_color"
                                       value="<?= htmlspecialchars($org['body_bg_color'] ?? '#f8f9fa') ?>">
                                <div class="form-text">Main background color of your storefront</div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Text Colors Section -->
                <div class="card mb-4 shadow-sm">
                    <div class="card-header bg-light">
                        <h5 class="mb-0"><i class="fas fa-font me-2"></i>Text Colors</h5>
                    </div>
                    <div class="card-body">
                        <div class="row mb-3">
                            <div class="col-md-6">
                                <label for="heading_color" class="form-label">
                                    <i class="fas fa-heading me-2" style="color: <?= htmlspecialchars($org['heading_color'] ?? '#212529') ?>"></i>
                                    Headings & Titles
                                </label>
                                <input type="color" class="form-control form-control-color" id="heading_color" name="heading_color"
                                       value="<?= htmlspecialchars($org['heading_color'] ?? '#212529') ?>">
                                <div class="form-text">Product titles, section headings, card titles</div>
                            </div>
                            <div class="col-md-6">
                                <label for="body_text_color" class="form-label">
                                    <i class="fas fa-paragraph me-2" style="color: <?= htmlspecialchars($org['body_text_color'] ?? '#212529') ?>"></i>
                                    Main Text
                                </label>
                                <input type="color" class="form-control form-control-color" id="body_text_color" name="body_text_color"
                                       value="<?= htmlspecialchars($org['body_text_color'] ?? '#212529') ?>">
                                <div class="form-text">General body text and descriptions</div>
                            </div>
                        </div>

                        <div class="row mb-3">
                            <div class="col-md-6">
                                <label for="muted_text_color" class="form-label">
                                    <i class="fas fa-text-height me-2" style="color: <?= htmlspecialchars($org['muted_text_color'] ?? '#6c757d') ?>"></i>
                                    Secondary Text
                                </label>
                                <input type="color" class="form-control form-control-color" id="muted_text_color" name="muted_text_color"
                                       value="<?= htmlspecialchars($org['muted_text_color'] ?? '#6c757d') ?>">
                                <div class="form-text">Dates, captions, less important information</div>
                            </div>
                            <div class="col-md-6">
                                <label for="link_color" class="form-label">
                                    <i class="fas fa-link me-2" style="color: <?= htmlspecialchars($org['link_color'] ?? '#0d6efd') ?>"></i>
                                    Links
                                </label>
                                <input type="color" class="form-control form-control-color" id="link_color" name="link_color"
                                       value="<?= htmlspecialchars($org['link_color'] ?? '#0d6efd') ?>">
                                <div class="form-text">Text links and navigation elements</div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Cards & Layout Section -->
                <div class="card mb-4 shadow-sm">
                    <div class="card-header bg-light">
                        <h5 class="mb-0"><i class="fas fa-layer-group me-2"></i>Cards & Layout</h5>
                    </div>
                    <div class="card-body">
                        <div class="row mb-3">
                            <div class="col-md-6">
                                <label for="card_bg_color" class="form-label">
                                    <i class="fas fa-square me-2" style="color: <?= htmlspecialchars($org['card_bg_color'] ?? '#ffffff') ?>; border: 1px solid #ccc;"></i>
                                    Card Background
                                </label>
                                <input type="color" class="form-control form-control-color" id="card_bg_color" name="card_bg_color"
                                       value="<?= htmlspecialchars($org['card_bg_color'] ?? '#ffffff') ?>">
                                <div class="form-text">Background color of product cards and content boxes</div>
                            </div>
                            <div class="col-md-6">
                                <label for="card_border_color" class="form-label">
                                    <i class="fas fa-border-style me-2" style="color: <?= htmlspecialchars($org['card_border_color'] ?? '#dee2e6') ?>"></i>
                                    Card Borders
                                </label>
                                <input type="color" class="form-control form-control-color" id="card_border_color" name="card_border_color"
                                       value="<?= htmlspecialchars($org['card_border_color'] ?? '#dee2e6') ?>">
                                <div class="form-text">Border color around cards and containers</div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Navigation Section -->
                <div class="card mb-4 shadow-sm">
                    <div class="card-header bg-light">
                        <h5 class="mb-0"><i class="fas fa-bars me-2"></i>Navigation Bar</h5>
                    </div>
                    <div class="card-body">
                        <div class="row mb-3">
                            <div class="col-md-6">
                                <label for="navbar_bg_color" class="form-label">
                                    <i class="fas fa-square me-2" style="color: <?= htmlspecialchars($org['navbar_bg_color'] ?? '#ffffff') ?>; border: 1px solid #ccc;"></i>
                                    Navigation Background
                                </label>
                                <input type="color" class="form-control form-control-color" id="navbar_bg_color" name="navbar_bg_color"
                                       value="<?= htmlspecialchars($org['navbar_bg_color'] ?? '#ffffff') ?>">
                                <div class="form-text">Background color of the top navigation bar</div>
                            </div>
                            <div class="col-md-6">
                                <label for="navbar_text_color" class="form-label">
                                    <i class="fas fa-font me-2" style="color: <?= htmlspecialchars($org['navbar_text_color'] ?? '#000000') ?>"></i>
                                    Navigation Text
                                </label>
                                <input type="color" class="form-control form-control-color" id="navbar_text_color" name="navbar_text_color"
                                       value="<?= htmlspecialchars($org['navbar_text_color'] ?? '#000000') ?>">
                                <div class="form-text">Color of text and logo in the navigation bar</div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Preview Section -->
                <div class="card mb-4 shadow-sm">
                    <div class="card-header bg-light">
                        <h5 class="mb-0"><i class="fas fa-eye me-2"></i>Live Preview</h5>
                    </div>
                    <div class="card-body">
                        <div class="border rounded p-3" style="background-color: var(--body-bg, #f8f9fa);">
                            <div class="rounded p-2 mb-3 d-flex align-items-center" style="background-color: var(--navbar-bg, #ffffff); border: 1px solid #dee2e6;">
                                <span style="color: var(--navbar-text, #000000); font-weight: bold;">
                                    <?php if (!empty($org['logo_path'])): ?>
                                        <img src="<?= BASE_URL ?>public/uploads/logos/<?= htmlspecialchars($org['logo_path']) ?>" 
                                             alt="Logo Preview" style="max-height: 30px; max-width: 100px;">
                                    <?php else: ?>
                                        <?= htmlspecialchars($org['organization_display_name'] ?: 'Your Store Name') ?>
                                    <?php endif; ?>
                                </span>
                            </div>
                            <div class="bg-white rounded p-3 mb-2 shadow-sm">
                                <h6 style="color: var(--primary, #f66903);">Sample Product Title</h6>
                                <p class="mb-1" style="color: var(--price, #198754); font-weight: bold;">$29.99</p>
                                <p class="text-muted small mb-2">Sample product description...</p>
                                <button class="btn btn-sm" style="background-color: var(--primary, #f66903); color: white; border: none;">View Details</button>
                            </div>
                        </div>
                        <div class="form-text mt-2">
                            <i class="fas fa-info-circle me-1"></i>
                            This preview updates as you change colors above. Visit your actual storefront to see the full effect.
                        </div>
                    </div>
                </div>

                <!-- Action Buttons Section -->
                <div class="action-buttons-container bg-light rounded p-3">
                    <!-- Main Action Buttons -->
                    <div class="main-actions d-flex gap-2 justify-content-end align-items-center">
                        <a href="<?= BASE_URL ?>storefront/manage" class="btn btn-outline-secondary btn-action">
                            <i class="fas fa-times me-2"></i>
                            <span class="btn-text">Cancel</span>
                        </a>
                        <button type="submit" name="save_profile" class="btn btn-success btn-action">
                            <i class="fas fa-save me-2"></i>
                            <span class="btn-text">Save Changes</span>
                        </button>
                    </div>
                    
                    <?php if (!empty($org['logo_path'])): ?>
                        <!-- Divider -->
                        <hr class="my-3 d-none d-md-block">
                        <div class="mt-3 d-md-none"></div>
                        
                        <!-- Secondary Actions -->
                        <div class="secondary-actions">
                            <form method="POST" onsubmit="return confirm('Are you sure you want to delete the logo? This action cannot be undone.');" class="d-inline-block">
                                <button type="submit" name="delete_logo" class="btn btn-sm btn-outline-danger btn-action-secondary">
                                    <i class="fas fa-trash me-2"></i>
                                    <span class="btn-text">Delete Current Logo</span>
                                </button>
                            </form>
                        </div>
                    <?php endif; ?>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- CSS for Live Preview -->
<style>
    :root {
        --primary: <?= htmlspecialchars($org['primary_color'] ?? '#f66903') ?>;
        --secondary: <?= htmlspecialchars($org['secondary_color'] ?? '#ff9e49') ?>;
        --navbar-bg: <?= htmlspecialchars($org['navbar_bg_color'] ?? '#ffffff') ?>;
        --navbar-text: <?= htmlspecialchars($org['navbar_text_color'] ?? '#000000') ?>;
        --body-bg: <?= htmlspecialchars($org['body_bg_color'] ?? '#f8f9fa') ?>;
        --price: <?= htmlspecialchars($org['price_color'] ?? '#198754') ?>;
    }

    .form-control-color {
        width: 100%;
        height: 50px;
    }

    .card-header {
        background-color: #f8f9fa;
        border-bottom: 1px solid #dee2e6;
    }

    .form-text {
        font-size: 0.875rem;
        color: #6c757d;
    }
    
    /* Action Buttons Styling */
    .action-buttons-container {
        margin-top: 2rem;
        padding-top: 1.5rem;
        border-top: 1px solid #dee2e6;
    }

    .main-actions {
        margin-bottom: 1rem;
    }

    .secondary-actions {
        display: flex;
        justify-content: center;
        padding-top: 1rem;
        border-top: 1px solid #f8f9fa;
    }

    .btn-action {
        min-width: 120px;
        padding: 0.625rem 1.25rem;
        font-weight: 500;
        transition: all 0.2s ease;
    }

    .btn-action-secondary {
        padding: 0.5rem 1rem;
        font-weight: 500;
        transition: all 0.2s ease;
        border-width: 1px;
    }

    .btn-action:hover,
    .btn-action-secondary:hover {
        transform: translateY(-1px);
        box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
    }

    /* Mobile Responsive Design */
    @media (max-width: 768px) {
        .main-actions {
            flex-direction: column;
            gap: 0.75rem !important;
        }
        
        .btn-action {
            width: 100%;
            min-width: unset;
            justify-content: center;
            padding: 0.75rem 1rem;
        }
        
        .secondary-actions {
            margin-top: 1rem;
        }
        
        .btn-action-secondary {
            width: 100%;
            max-width: 300px;
            justify-content: center;
        }
    }

    /* Small Mobile Adjustments */
    @media (max-width: 576px) {
        .action-buttons-container {
            margin-top: 1.5rem;
            padding-top: 1rem;
        }
        
        .btn-text {
            font-size: 0.9rem;
        }
        
        .btn-action i,
        .btn-action-secondary i {
            font-size: 0.9rem;
        }
        
        .main-actions {
            gap: 0.5rem !important;
        }
    }

    /* Desktop Enhancements */
    @media (min-width: 769px) {
        .main-actions {
            align-items: center;
        }
        
        .secondary-actions {
            justify-content: flex-end;
            padding-right: 0;
        }
        
        .btn-action-secondary {
            min-width: 180px;
        }
    }

    /* Button Focus States */
    .btn-action:focus,
    .btn-action-secondary:focus {
        box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);
        outline: none;
    }

    /* Success Button Custom Styling */
    .btn-success.btn-action {
        background-color: #28a745;
        border-color: #28a745;
    }

    .btn-success.btn-action:hover {
        background-color: #218838;
        border-color: #1e7e34;
    }

    /* Danger Button Custom Styling */
    .btn-outline-danger.btn-action-secondary:hover {
        background-color: #dc3545;
        border-color: #dc3545;
        color: white;
    }

    /* Card shadow improvements */
    .card.shadow-sm {
        box-shadow: 0 0.125rem 0.25rem rgba(0, 0, 0, 0.075);
        border: 1px solid rgba(0, 0, 0, 0.125);
    }

    .card.shadow-sm:hover {
        box-shadow: 0 0.5rem 1rem rgba(0, 0, 0, 0.15);
        transition: box-shadow 0.2s ease;
    }
</style>

<!-- JavaScript for Live Preview Updates -->
<script>
document.addEventListener('DOMContentLoaded', function() {
    const colorInputs = {
        'primary_color': '--primary',
        'secondary_color': '--secondary', 
        'navbar_bg_color': '--navbar-bg',
        'navbar_text_color': '--navbar-text',
        'body_bg_color': '--body-bg',
        'price_color': '--price'
    };

    Object.keys(colorInputs).forEach(inputId => {
        const input = document.getElementById(inputId);
        if (input) {
            input.addEventListener('input', function() {
                document.documentElement.style.setProperty(colorInputs[inputId], this.value);
            });
        }
    });
});
</script>

<?php include __DIR__ . '/../../partials/footer.php'; ?>